@@ -1,12 +1,12 @@
 import argparse
 
 
-__version__ = '0.1.0'
+__version__ = '0.6.0'
 
 
-class IntegerRangeType:
+class Integer:
 
-    def __init__(self, minimum, maximum):
+    def __init__(self, minimum=None, maximum=None):
         self.minimum = minimum
         self.maximum = maximum
 
@@ -20,11 +20,11 @@ class IntegerRangeType:
         elif self.minimum is not None:
             if value < self.minimum:
                 raise argparse.ArgumentTypeError(
-                    f'{string} is not {self.minimum} or higher')
+                    f'{string} is not in the range {self.minimum}..inf')
         elif self.maximum is not None:
             if value > self.maximum:
                 raise argparse.ArgumentTypeError(
-                    f'{string} is not {self.maximum} or lower')
+                    f'{string} is not in the range -inf..{self.maximum}')
 
         return value
 
